pub fn process_get_command(command: &KenkuGetCommand, base_url: &str) -> StringExpand description
Processes a GET command for the Kenku Remote server.
This function takes a KenkuGetCommand, an IP address, and a port, and returns
a String containing the corresponding URL for the command on the Kenku Remote server.
Arguments
command- AKenkuGetCommandenum representing the type of GET command to process.base_url- A string slice containg the url of the kenku remote
Returns
Returns a String containing the formatted URL corresponding to the command on the Kenku Remote server.